"""This module contains the general information for SwEnvStatsHist ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class SwEnvStatsHistConsts():
    FAN_CTRLR_INLET1_NOT_APPLICABLE = "not-applicable"
    FAN_CTRLR_INLET1_AVG_NOT_APPLICABLE = "not-applicable"
    FAN_CTRLR_INLET1_MAX_NOT_APPLICABLE = "not-applicable"
    FAN_CTRLR_INLET1_MIN_NOT_APPLICABLE = "not-applicable"
    FAN_CTRLR_INLET2_NOT_APPLICABLE = "not-applicable"
    FAN_CTRLR_INLET2_AVG_NOT_APPLICABLE = "not-applicable"
    FAN_CTRLR_INLET2_MAX_NOT_APPLICABLE = "not-applicable"
    FAN_CTRLR_INLET2_MIN_NOT_APPLICABLE = "not-applicable"
    FAN_CTRLR_INLET3_NOT_APPLICABLE = "not-applicable"
    FAN_CTRLR_INLET3_AVG_NOT_APPLICABLE = "not-applicable"
    FAN_CTRLR_INLET3_MAX_NOT_APPLICABLE = "not-applicable"
    FAN_CTRLR_INLET3_MIN_NOT_APPLICABLE = "not-applicable"
    FAN_CTRLR_INLET4_NOT_APPLICABLE = "not-applicable"
    FAN_CTRLR_INLET4_AVG_NOT_APPLICABLE = "not-applicable"
    FAN_CTRLR_INLET4_MAX_NOT_APPLICABLE = "not-applicable"
    FAN_CTRLR_INLET4_MIN_NOT_APPLICABLE = "not-applicable"
    MAIN_BOARD_OUTLET1_NOT_APPLICABLE = "not-applicable"
    MAIN_BOARD_OUTLET1_AVG_NOT_APPLICABLE = "not-applicable"
    MAIN_BOARD_OUTLET1_MAX_NOT_APPLICABLE = "not-applicable"
    MAIN_BOARD_OUTLET1_MIN_NOT_APPLICABLE = "not-applicable"
    MAIN_BOARD_OUTLET2_NOT_APPLICABLE = "not-applicable"
    MAIN_BOARD_OUTLET2_AVG_NOT_APPLICABLE = "not-applicable"
    MAIN_BOARD_OUTLET2_MAX_NOT_APPLICABLE = "not-applicable"
    MAIN_BOARD_OUTLET2_MIN_NOT_APPLICABLE = "not-applicable"
    MOST_RECENT_FALSE = "false"
    MOST_RECENT_NO = "no"
    MOST_RECENT_TRUE = "true"
    MOST_RECENT_YES = "yes"
    PSU_CTRLR_INLET1_NOT_APPLICABLE = "not-applicable"
    PSU_CTRLR_INLET1_AVG_NOT_APPLICABLE = "not-applicable"
    PSU_CTRLR_INLET1_MAX_NOT_APPLICABLE = "not-applicable"
    PSU_CTRLR_INLET1_MIN_NOT_APPLICABLE = "not-applicable"
    PSU_CTRLR_INLET2_NOT_APPLICABLE = "not-applicable"
    PSU_CTRLR_INLET2_AVG_NOT_APPLICABLE = "not-applicable"
    PSU_CTRLR_INLET2_MAX_NOT_APPLICABLE = "not-applicable"
    PSU_CTRLR_INLET2_MIN_NOT_APPLICABLE = "not-applicable"
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class SwEnvStatsHist(ManagedObject):
    """This is SwEnvStatsHist class."""

    consts = SwEnvStatsHistConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("SwEnvStatsHist", "swEnvStatsHist", "[id]", VersionMeta.Version111a, "OutputOnly", 0xf, [], ["read-only"], ['swEnvStats'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "fan_ctrlr_inlet1": MoPropertyMeta("fan_ctrlr_inlet1", "fanCtrlrInlet1", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "fan_ctrlr_inlet1_avg": MoPropertyMeta("fan_ctrlr_inlet1_avg", "fanCtrlrInlet1Avg", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "fan_ctrlr_inlet1_max": MoPropertyMeta("fan_ctrlr_inlet1_max", "fanCtrlrInlet1Max", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "fan_ctrlr_inlet1_min": MoPropertyMeta("fan_ctrlr_inlet1_min", "fanCtrlrInlet1Min", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "fan_ctrlr_inlet2": MoPropertyMeta("fan_ctrlr_inlet2", "fanCtrlrInlet2", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "fan_ctrlr_inlet2_avg": MoPropertyMeta("fan_ctrlr_inlet2_avg", "fanCtrlrInlet2Avg", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "fan_ctrlr_inlet2_max": MoPropertyMeta("fan_ctrlr_inlet2_max", "fanCtrlrInlet2Max", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "fan_ctrlr_inlet2_min": MoPropertyMeta("fan_ctrlr_inlet2_min", "fanCtrlrInlet2Min", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "fan_ctrlr_inlet3": MoPropertyMeta("fan_ctrlr_inlet3", "fanCtrlrInlet3", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "fan_ctrlr_inlet3_avg": MoPropertyMeta("fan_ctrlr_inlet3_avg", "fanCtrlrInlet3Avg", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "fan_ctrlr_inlet3_max": MoPropertyMeta("fan_ctrlr_inlet3_max", "fanCtrlrInlet3Max", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "fan_ctrlr_inlet3_min": MoPropertyMeta("fan_ctrlr_inlet3_min", "fanCtrlrInlet3Min", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "fan_ctrlr_inlet4": MoPropertyMeta("fan_ctrlr_inlet4", "fanCtrlrInlet4", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "fan_ctrlr_inlet4_avg": MoPropertyMeta("fan_ctrlr_inlet4_avg", "fanCtrlrInlet4Avg", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "fan_ctrlr_inlet4_max": MoPropertyMeta("fan_ctrlr_inlet4_max", "fanCtrlrInlet4Max", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "fan_ctrlr_inlet4_min": MoPropertyMeta("fan_ctrlr_inlet4_min", "fanCtrlrInlet4Min", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "id": MoPropertyMeta("id", "id", "ulong", VersionMeta.Version111a, MoPropertyMeta.NAMING, None, None, None, None, [], []), 
        "main_board_outlet1": MoPropertyMeta("main_board_outlet1", "mainBoardOutlet1", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "main_board_outlet1_avg": MoPropertyMeta("main_board_outlet1_avg", "mainBoardOutlet1Avg", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "main_board_outlet1_max": MoPropertyMeta("main_board_outlet1_max", "mainBoardOutlet1Max", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "main_board_outlet1_min": MoPropertyMeta("main_board_outlet1_min", "mainBoardOutlet1Min", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "main_board_outlet2": MoPropertyMeta("main_board_outlet2", "mainBoardOutlet2", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "main_board_outlet2_avg": MoPropertyMeta("main_board_outlet2_avg", "mainBoardOutlet2Avg", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "main_board_outlet2_max": MoPropertyMeta("main_board_outlet2_max", "mainBoardOutlet2Max", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "main_board_outlet2_min": MoPropertyMeta("main_board_outlet2_min", "mainBoardOutlet2Min", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "most_recent": MoPropertyMeta("most_recent", "mostRecent", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "psu_ctrlr_inlet1": MoPropertyMeta("psu_ctrlr_inlet1", "psuCtrlrInlet1", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "psu_ctrlr_inlet1_avg": MoPropertyMeta("psu_ctrlr_inlet1_avg", "psuCtrlrInlet1Avg", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "psu_ctrlr_inlet1_max": MoPropertyMeta("psu_ctrlr_inlet1_max", "psuCtrlrInlet1Max", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "psu_ctrlr_inlet1_min": MoPropertyMeta("psu_ctrlr_inlet1_min", "psuCtrlrInlet1Min", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "psu_ctrlr_inlet2": MoPropertyMeta("psu_ctrlr_inlet2", "psuCtrlrInlet2", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "psu_ctrlr_inlet2_avg": MoPropertyMeta("psu_ctrlr_inlet2_avg", "psuCtrlrInlet2Avg", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "psu_ctrlr_inlet2_max": MoPropertyMeta("psu_ctrlr_inlet2_max", "psuCtrlrInlet2Max", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "psu_ctrlr_inlet2_min": MoPropertyMeta("psu_ctrlr_inlet2_min", "psuCtrlrInlet2Min", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "fanCtrlrInlet1": "fan_ctrlr_inlet1", 
        "fanCtrlrInlet1Avg": "fan_ctrlr_inlet1_avg", 
        "fanCtrlrInlet1Max": "fan_ctrlr_inlet1_max", 
        "fanCtrlrInlet1Min": "fan_ctrlr_inlet1_min", 
        "fanCtrlrInlet2": "fan_ctrlr_inlet2", 
        "fanCtrlrInlet2Avg": "fan_ctrlr_inlet2_avg", 
        "fanCtrlrInlet2Max": "fan_ctrlr_inlet2_max", 
        "fanCtrlrInlet2Min": "fan_ctrlr_inlet2_min", 
        "fanCtrlrInlet3": "fan_ctrlr_inlet3", 
        "fanCtrlrInlet3Avg": "fan_ctrlr_inlet3_avg", 
        "fanCtrlrInlet3Max": "fan_ctrlr_inlet3_max", 
        "fanCtrlrInlet3Min": "fan_ctrlr_inlet3_min", 
        "fanCtrlrInlet4": "fan_ctrlr_inlet4", 
        "fanCtrlrInlet4Avg": "fan_ctrlr_inlet4_avg", 
        "fanCtrlrInlet4Max": "fan_ctrlr_inlet4_max", 
        "fanCtrlrInlet4Min": "fan_ctrlr_inlet4_min", 
        "id": "id", 
        "mainBoardOutlet1": "main_board_outlet1", 
        "mainBoardOutlet1Avg": "main_board_outlet1_avg", 
        "mainBoardOutlet1Max": "main_board_outlet1_max", 
        "mainBoardOutlet1Min": "main_board_outlet1_min", 
        "mainBoardOutlet2": "main_board_outlet2", 
        "mainBoardOutlet2Avg": "main_board_outlet2_avg", 
        "mainBoardOutlet2Max": "main_board_outlet2_max", 
        "mainBoardOutlet2Min": "main_board_outlet2_min", 
        "mostRecent": "most_recent", 
        "psuCtrlrInlet1": "psu_ctrlr_inlet1", 
        "psuCtrlrInlet1Avg": "psu_ctrlr_inlet1_avg", 
        "psuCtrlrInlet1Max": "psu_ctrlr_inlet1_max", 
        "psuCtrlrInlet1Min": "psu_ctrlr_inlet1_min", 
        "psuCtrlrInlet2": "psu_ctrlr_inlet2", 
        "psuCtrlrInlet2Avg": "psu_ctrlr_inlet2_avg", 
        "psuCtrlrInlet2Max": "psu_ctrlr_inlet2_max", 
        "psuCtrlrInlet2Min": "psu_ctrlr_inlet2_min", 
        "rn": "rn", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.child_action = None
        self.fan_ctrlr_inlet1 = None
        self.fan_ctrlr_inlet1_avg = None
        self.fan_ctrlr_inlet1_max = None
        self.fan_ctrlr_inlet1_min = None
        self.fan_ctrlr_inlet2 = None
        self.fan_ctrlr_inlet2_avg = None
        self.fan_ctrlr_inlet2_max = None
        self.fan_ctrlr_inlet2_min = None
        self.fan_ctrlr_inlet3 = None
        self.fan_ctrlr_inlet3_avg = None
        self.fan_ctrlr_inlet3_max = None
        self.fan_ctrlr_inlet3_min = None
        self.fan_ctrlr_inlet4 = None
        self.fan_ctrlr_inlet4_avg = None
        self.fan_ctrlr_inlet4_max = None
        self.fan_ctrlr_inlet4_min = None
        self.main_board_outlet1 = None
        self.main_board_outlet1_avg = None
        self.main_board_outlet1_max = None
        self.main_board_outlet1_min = None
        self.main_board_outlet2 = None
        self.main_board_outlet2_avg = None
        self.main_board_outlet2_max = None
        self.main_board_outlet2_min = None
        self.most_recent = None
        self.psu_ctrlr_inlet1 = None
        self.psu_ctrlr_inlet1_avg = None
        self.psu_ctrlr_inlet1_max = None
        self.psu_ctrlr_inlet1_min = None
        self.psu_ctrlr_inlet2 = None
        self.psu_ctrlr_inlet2_avg = None
        self.psu_ctrlr_inlet2_max = None
        self.psu_ctrlr_inlet2_min = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None

        ManagedObject.__init__(self, "SwEnvStatsHist", parent_mo_or_dn, **kwargs)




"""This module contains the meta information of OrgGetSubscribedDomains ExternalMethod."""

from ..ucsccoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("OrgGetSubscribedDomains", "orgGetSubscribedDomains", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_class_id": MethodPropertyMeta("InClassId", "inClassId", "Xs:unsignedInt", "Version142b", "Input", False),
    "in_domain_group_dn": MethodPropertyMeta("InDomainGroupDn", "inDomainGroupDn", "ReferenceObject", "Version142b", "Input", False),
    "in_subscription_type": MethodPropertyMeta("InSubscriptionType", "inSubscriptionType", "Xs:string", "Version142b", "Input", False),
    "out_subscribed": MethodPropertyMeta("OutSubscribed", "outSubscribed", "ConfigSet", "Version142b", "Output", True),
    "out_unsubscribed": MethodPropertyMeta("OutUnsubscribed", "outUnsubscribed", "ConfigSet", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "inClassId": "in_class_id",
    "inDomainGroupDn": "in_domain_group_dn",
    "inSubscriptionType": "in_subscription_type",
    "outSubscribed": "out_subscribed",
    "outUnsubscribed": "out_unsubscribed",
}




"""This module contains the general information for BiosUnit ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class BiosUnitConsts():
    INIT_TS_NEVER = "never"


class BiosUnit(ManagedObject):
    """This is BiosUnit class."""

    consts = BiosUnitConsts()
    naming_props = set([])

    mo_meta = MoMeta("BiosUnit", "biosUnit", "bios", VersionMeta.Version111a, "InputOutput", 0xf, [], ["read-only"], ['computeBlade', 'computeRackUnit', 'computeServerUnit'], ['biosBOT', 'firmwareRunning'], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "init_seq": MoPropertyMeta("init_seq", "initSeq", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "init_ts": MoPropertyMeta("init_ts", "initTs", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", ["never"], []), 
        "model": MoPropertyMeta("model", "model", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "revision": MoPropertyMeta("revision", "revision", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "serial": MoPropertyMeta("serial", "serial", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "vendor": MoPropertyMeta("vendor", "vendor", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "initSeq": "init_seq", 
        "initTs": "init_ts", 
        "model": "model", 
        "revision": "revision", 
        "rn": "rn", 
        "serial": "serial", 
        "status": "status", 
        "vendor": "vendor", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.init_seq = None
        self.init_ts = None
        self.model = None
        self.revision = None
        self.serial = None
        self.status = None
        self.vendor = None

        ManagedObject.__init__(self, "BiosUnit", parent_mo_or_dn, **kwargs)




"""This module contains the general information for InitiatorRequestorGrpEp ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class InitiatorRequestorGrpEpConsts():
    ALLOC_STATE_ALLOCATED = "allocated"
    ALLOC_STATE_ALLOCATING = "allocating"
    ALLOC_STATE_FAILED = "failed"
    ALLOC_STATE_NONE = "none"
    LC_ALLOCATED = "allocated"
    LC_AVAILABLE = "available"
    LC_DEALLOCATED = "deallocated"
    LC_REPURPOSED = "repurposed"
    TYPE_DEDICATED = "dedicated"
    TYPE_POLICY = "policy"
    TYPE_SHARED = "shared"


class InitiatorRequestorGrpEp(ManagedObject):
    """This is InitiatorRequestorGrpEp class."""

    consts = InitiatorRequestorGrpEpConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("InitiatorRequestorGrpEp", "initiatorRequestorGrpEp", "req-grp-[id]", VersionMeta.Version131a, "InputOutput", 0x1f, [], ["read-only"], ['topSystem'], ['initiatorMemberEp', 'initiatorUnitEp'], [None])

    prop_meta = {
        "alloc_state": MoPropertyMeta("alloc_state", "allocState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["allocated", "allocating", "failed", "none"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "ep_dn": MoPropertyMeta("ep_dn", "epDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version131a, MoPropertyMeta.NAMING, 0x4, None, None, None, [], []), 
        "lc": MoPropertyMeta("lc", "lc", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["allocated", "available", "deallocated", "repurposed"], []), 
        "pol_dn": MoPropertyMeta("pol_dn", "polDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["dedicated", "policy", "shared"], []), 
    }

    prop_map = {
        "allocState": "alloc_state", 
        "childAction": "child_action", 
        "dn": "dn", 
        "epDn": "ep_dn", 
        "id": "id", 
        "lc": "lc", 
        "polDn": "pol_dn", 
        "rn": "rn", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.alloc_state = None
        self.child_action = None
        self.ep_dn = None
        self.lc = None
        self.pol_dn = None
        self.status = None
        self.type = None

        ManagedObject.__init__(self, "InitiatorRequestorGrpEp", parent_mo_or_dn, **kwargs)




"""This module contains the general information for PolicyControlEp ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class PolicyControlEpConsts():
    ACK_STATE_ACKED = "acked"
    ACK_STATE_NO_ACK = "no-ack"
    ACK_STATE_REMOTE_TRIGGER = "remoteTrigger"
    REGISTRATION_STATE_FAILED = "failed"
    REGISTRATION_STATE_INPROGRESS = "inprogress"
    REGISTRATION_STATE_LOST_VISIBILITY = "lost-visibility"
    REGISTRATION_STATE_REGISTERED = "registered"
    REGISTRATION_STATE_UNREGISTERED = "unregistered"
    SUSPEND_STATE_OFF = "off"
    SUSPEND_STATE_ON = "on"
    SUSPEND_STATE_REMOTE_TRIGGER = "remoteTrigger"
    TYPE_POLICY = "policy"


class PolicyControlEp(ManagedObject):
    """This is PolicyControlEp class."""

    consts = PolicyControlEpConsts()
    naming_props = set([])

    mo_meta = MoMeta("PolicyControlEp", "policyControlEp", "control-ep-policy", VersionMeta.Version121a, "InputOutput", 0x1ff, [], ["admin"], ['computeSystem', 'fabricSystem'], ['policyCommunication', 'policyConfigBackup', 'policyControlEpOperation', 'policyDateTime', 'policyDestEp', 'policyDiscovery', 'policyDns', 'policyEquipment', 'policyFault', 'policyInfraFirmware', 'policyMEp', 'policyModularChassisFan', 'policyMonitoring', 'policyPortConfig', 'policyPowerExtended', 'policyPowerMgmt', 'policyPowerSave', 'policyPsu', 'policySecurity', 'policySourceApp', 'policyStorageAutoConfig'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "ack_state": MoPropertyMeta("ack_state", "ackState", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["acked", "no-ack", "remoteTrigger"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version121a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "registration_state": MoPropertyMeta("registration_state", "registrationState", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["failed", "inprogress", "lost-visibility", "registered", "unregistered"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "secret": MoPropertyMeta("secret", "secret", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[!""#%&'\(\)\*\+,\-\./:;<>@\[\\\]\^_`\{\|\}~a-zA-Z0-9]{0,64}""", [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "suspend_state": MoPropertyMeta("suspend_state", "suspendState", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["off", "on", "remoteTrigger"], []), 
        "svc_reg_name": MoPropertyMeta("svc_reg_name", "svcRegName", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""^[A-Za-z]([A-Za-z0-9_.-]*[A-Za-z0-9])?([A-Za-z]([A-Za-z0-9._-]*[A-Za-z0-9])?)*$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])$|^([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}$|^([0-9a-fA-F]{1,4}:){1,7}:$|^([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}$|^([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}$|^([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}$|^([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}$|^([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}$|^[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})$|^:((:[0-9a-fA-F]{1,4}){1,7}|:)$""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, ["policy"], []), 
    }

    prop_map = {
        "ackState": "ack_state", 
        "childAction": "child_action", 
        "dn": "dn", 
        "registrationState": "registration_state", 
        "rn": "rn", 
        "secret": "secret", 
        "status": "status", 
        "suspendState": "suspend_state", 
        "svcRegName": "svc_reg_name", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.ack_state = None
        self.child_action = None
        self.registration_state = None
        self.secret = None
        self.status = None
        self.suspend_state = None
        self.svc_reg_name = None
        self.type = None

        ManagedObject.__init__(self, "PolicyControlEp", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ExtmgmtNdiscTargets ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ExtmgmtNdiscTargetsConsts():
    CONFIG_STATE_NOT_APPLIED = "not-applied"
    CONFIG_STATE_OK = "ok"


class ExtmgmtNdiscTargets(ManagedObject):
    """This is ExtmgmtNdiscTargets class."""

    consts = ExtmgmtNdiscTargetsConsts()
    naming_props = set([])

    mo_meta = MoMeta("ExtmgmtNdiscTargets", "extmgmtNdiscTargets", "ndisc-target-policy", VersionMeta.Version112a, "InputOutput", 0x1ff, [], ["admin", "domain-group-management", "ext-lan-config"], ['extmgmtIfMonPolicy'], [], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version112a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "config_state": MoPropertyMeta("config_state", "configState", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applied", "ok"], []), 
        "config_status_message": MoPropertyMeta("config_status_message", "configStatusMessage", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "ipv6_target1": MoPropertyMeta("ipv6_target1", "ipv6Target1", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x4, 0, 256, None, [], []), 
        "ipv6_target2": MoPropertyMeta("ipv6_target2", "ipv6Target2", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x8, 0, 256, None, [], []), 
        "ipv6_target3": MoPropertyMeta("ipv6_target3", "ipv6Target3", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x10, 0, 256, None, [], []), 
        "max_deadline_timeout": MoPropertyMeta("max_deadline_timeout", "maxDeadlineTimeout", "uint", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, [], ["5-15"]), 
        "number_of_ndisc_requests": MoPropertyMeta("number_of_ndisc_requests", "numberOfNdiscRequests", "uint", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, [], ["1-5"]), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, 0x80, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "configState": "config_state", 
        "configStatusMessage": "config_status_message", 
        "dn": "dn", 
        "ipv6Target1": "ipv6_target1", 
        "ipv6Target2": "ipv6_target2", 
        "ipv6Target3": "ipv6_target3", 
        "maxDeadlineTimeout": "max_deadline_timeout", 
        "numberOfNdiscRequests": "number_of_ndisc_requests", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.config_state = None
        self.config_status_message = None
        self.ipv6_target1 = None
        self.ipv6_target2 = None
        self.ipv6_target3 = None
        self.max_deadline_timeout = None
        self.number_of_ndisc_requests = None
        self.status = None

        ManagedObject.__init__(self, "ExtmgmtNdiscTargets", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ConfigInputConfig ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ConfigInputConfigConsts():
    pass


class ConfigInputConfig(ManagedObject):
    """This is ConfigInputConfig class."""

    consts = ConfigInputConfigConsts()
    naming_props = set(['inputName', 'inputConfigStatus'])

    mo_meta = MoMeta("ConfigInputConfig", "configInputConfig", "name-[input_name]status-[input_config_status]", VersionMeta.Version111a, "InputOutput", 0x3f, [], ["read-only"], ['configInputConfigSet'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "config_dn": MoPropertyMeta("config_dn", "configDn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "input_config_status": MoPropertyMeta("input_config_status", "inputConfigStatus", "string", VersionMeta.Version111a, MoPropertyMeta.NAMING, 0x4, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "input_name": MoPropertyMeta("input_name", "inputName", "string", VersionMeta.Version111a, MoPropertyMeta.NAMING, 0x8, 1, 510, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "configDn": "config_dn", 
        "dn": "dn", 
        "inputConfigStatus": "input_config_status", 
        "inputName": "input_name", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, input_name, input_config_status, **kwargs):
        self._dirty_mask = 0
        self.input_name = input_name
        self.input_config_status = input_config_status
        self.child_action = None
        self.config_dn = None
        self.status = None

        ManagedObject.__init__(self, "ConfigInputConfig", parent_mo_or_dn, **kwargs)




"""This module contains the meta information of ConfigGetLastBackedUpDomains ExternalMethod."""

from ..ucsccoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ConfigGetLastBackedUpDomains", "configGetLastBackedUpDomains", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_backup_type": MethodPropertyMeta("InBackupType", "inBackupType", "Xs:string", "Version142b", "Input", False),
    "in_domains": MethodPropertyMeta("InDomains", "inDomains", "DnSet", "Version142b", "Input", True),
    "out_config_backup": MethodPropertyMeta("OutConfigBackup", "outConfigBackup", "ConfigSet", "Version142b", "Output", True),
    "out_empty_backup_clients": MethodPropertyMeta("OutEmptyBackupClients", "outEmptyBackupClients", "ConfigSet", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "inBackupType": "in_backup_type",
    "inDomains": "in_domains",
    "outConfigBackup": "out_config_backup",
    "outEmptyBackupClients": "out_empty_backup_clients",
}




"""This module contains the general information for FcpoolBootTarget ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FcpoolBootTargetConsts():
    LUN_UNSPECIFIED = "unspecified"


class FcpoolBootTarget(ManagedObject):
    """This is FcpoolBootTarget class."""

    consts = FcpoolBootTargetConsts()
    naming_props = set(['type'])

    mo_meta = MoMeta("FcpoolBootTarget", "fcpoolBootTarget", "target-[type]", VersionMeta.Version101a, "InputOutput", 0x7f, [], ["admin", "ls-storage-policy"], ['fcpoolBlock', 'fcpoolInitiator'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "lun": MoPropertyMeta("lun", "lun", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["unspecified"], ["0-4294967295"]), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x20, None, None, None, [], []), 
        "wwn": MoPropertyMeta("wwn", "wwn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x40, 0, 256, r"""(([A-Fa-f0-9][A-Fa-f0-9]:){7}[A-Fa-f0-9][A-Fa-f0-9])|0""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "lun": "lun", 
        "rn": "rn", 
        "status": "status", 
        "type": "type", 
        "wwn": "wwn", 
    }

    def __init__(self, parent_mo_or_dn, type, **kwargs):
        self._dirty_mask = 0
        self.type = type
        self.child_action = None
        self.lun = None
        self.status = None
        self.wwn = None

        ManagedObject.__init__(self, "FcpoolBootTarget", parent_mo_or_dn, **kwargs)




#!/usr/bin/env python
# -*- coding: utf-8 -*-


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


with open('README.md') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read().replace('.. :changelog:', '')

setup(
    name='ucscsdk',
    version='0.9.0.10',
    description="Python SDK for Cisco Ucs Central",
    long_description=readme + '\n\n' + history,
    long_description_content_type='text/markdown',
    author="Cisco Systemc Inc.",
    author_email='ucs-python@cisco.com',
    url='https://github.com/ciscoucs/ucscsdk',
    packages=[
        'ucscsdk',
    ],
    package_dir={'ucscsdk':
                 'ucscsdk'},
    include_package_data=True,
    install_requires=['pyparsing', 'six'],
    license="http://www.apache.org/licenses/LICENSE-2.0",
    zip_safe=False,
    keywords='ucscsdk',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    tests_require=['nose'],
    test_suite='nose.collector',
    extras_require={
        'ssl': ['pyOpenSSL'],
        'docs': ['sphinx<1.3', 'sphinxcontrib-napoleon', 'sphinx_rtd_theme'],
    }
)



"""This module contains the general information for MacpoolFormat ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class MacpoolFormatConsts():
    MASK_FF_FF_FF_FF_FF_FX = "FF-FF-FF-FF-FF-Fx"
    MASK_FF_FF_FF_FF_FF_XX = "FF-FF-FF-FF-FF-xx"
    MASK_FF_FF_FF_FF_FX_XX = "FF-FF-FF-FF-Fx-xx"
    MASK_FF_FF_FF_FF_XX_XX = "FF-FF-FF-FF-xx-xx"
    MASK_FF_FF_FF_FX_XX_XX = "FF-FF-FF-Fx-xx-xx"
    MASK_FF_FF_FF_XX_XX_XX = "FF-FF-FF-xx-xx-xx"
    MASK_FF_FF_FX_XX_XX_XX = "FF-FF-Fx-xx-xx-xx"
    MASK_FF_FF_XX_XX_XX_XX = "FF-FF-xx-xx-xx-xx"
    MASK_FF_FX_XX_XX_XX_XX = "FF-Fx-xx-xx-xx-xx"
    MASK_FF_XX_XX_XX_XX_XX = "FF-xx-xx-xx-xx-xx"
    MASK_FX_XX_XX_XX_XX_XX = "Fx-xx-xx-xx-xx-xx"


class MacpoolFormat(ManagedObject):
    """This is MacpoolFormat class."""

    consts = MacpoolFormatConsts()
    naming_props = set(['format', 'mask'])

    mo_meta = MoMeta("MacpoolFormat", "macpoolFormat", "format-[format]-[mask]", VersionMeta.Version101a, "InputOutput", 0x3f, [], ["admin", "ext-lan-config", "ext-lan-policy", "ls-network", "ls-network-policy"], ['macpoolUniverse'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "format": MoPropertyMeta("format", "format", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x4, None, None, r"""(([0-9a-fA-F][0-9a-fA-F]:){5}([0-9a-fA-F][0-9a-fA-F]))|0""", [], []), 
        "mask": MoPropertyMeta("mask", "mask", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x8, None, None, None, ["FF-FF-FF-FF-FF-Fx", "FF-FF-FF-FF-FF-xx", "FF-FF-FF-FF-Fx-xx", "FF-FF-FF-FF-xx-xx", "FF-FF-FF-Fx-xx-xx", "FF-FF-FF-xx-xx-xx", "FF-FF-Fx-xx-xx-xx", "FF-FF-xx-xx-xx-xx", "FF-Fx-xx-xx-xx-xx", "FF-xx-xx-xx-xx-xx", "Fx-xx-xx-xx-xx-xx"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "format": "format", 
        "mask": "mask", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, format, mask, **kwargs):
        self._dirty_mask = 0
        self.format = format
        self.mask = mask
        self.child_action = None
        self.status = None

        ManagedObject.__init__(self, "MacpoolFormat", parent_mo_or_dn, **kwargs)




# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from nose.tools import *
from ucscsdk.ucscfilter import generate_infilter
from ucscsdk.ucscxmlcodec import to_xml_str

success = True


def ls_filter():
    global success
    filter_ = generate_infilter(class_id="lsServer",
                                filter_str='(type, "instance", type="eq")',
                                is_meta_class_id=True)
    expected = b'<filter><eq class="lsServer" property="type" ' \
               b'value="instance" /></filter>'
    if to_xml_str(filter_.to_xml()) != expected:
        success = False


def org_filter():
    global success
    filter_ = generate_infilter(class_id="orgOrg",
                                filter_str='(descr, "oroorg", type="eq")',
                                is_meta_class_id=True)
    expected = b'<filter><eq class="orgOrg" property="descr" ' \
               b'value="oroorg" /></filter>'
    if to_xml_str(filter_.to_xml()) != expected:
        success = False


def test_001_not_filter():

    expected = b'<filter><not><eq class="lsServer" property="dn" ' \
               b'value="org-root/ls-C1_B1" /></not></filter>'

    filter_str = 'not (dn,"org-root/ls-C1_B1", type="eq")'
    filter_xml = generate_infilter(class_id="LsServer",
                                   filter_str=filter_str,
                                   is_meta_class_id=True)

    xml_str = to_xml_str(filter_xml.to_xml())

    assert_equal(xml_str, expected)


def test_002_multi_thread_filter():
    import threading
    import time

    for i in range(1, 50):
        if i % 2 != 0:
            target = ls_filter
        else:
            target = org_filter

        thread = threading.Thread(name=i, target=target)
        thread.start()

    while len(threading.enumerate()) > 1:
        time.sleep(1)

    assert success


def test_003_mixed_filter():

    expected = b'<filter>' \
               b'<not>' \
               b'<or>' \
               b'<eq class="lsServer" property="type" value="instance" />' \
               b'<and><eq class="lsServer" property="usrLbl" ' \
               b'value="lsserver" />' \
               b'<not><wcard class="lsServer" property="descr" ' \
               b'value="description" />' \
               b'</not>' \
               b'</and>' \
               b'</or>' \
               b'</not>' \
               b'</filter>'

    filter_str = 'not(' \
                 '(type, "instance", type="eq") or ' \
                 '(usr_lbl, "lsserver", type="eq") and ' \
                 'not(descr, "description", type="re"))'
    filter_xml = generate_infilter(class_id="LsServer",
                                   filter_str=filter_str,
                                   is_meta_class_id=True)

    xml_str = to_xml_str(filter_xml.to_xml())

    assert_equal(xml_str, expected)



"""This module contains the general information for ComputeResourceAggrEp ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ComputeResourceAggrEpConsts():
    POLLING_INTERVAL_10_MIN = "10 min"
    POLLING_INTERVAL_15_MIN = "15 min"
    POLLING_INTERVAL_20_MIN = "20 min"
    POLLING_INTERVAL_30_MIN = "30 min"
    POLLING_INTERVAL_45_MIN = "45 min"
    POLLING_INTERVAL_5_MIN = "5 min"
    POLLING_INTERVAL_60_MIN = "60 min"


class ComputeResourceAggrEp(ManagedObject):
    """This is ComputeResourceAggrEp class."""

    consts = ComputeResourceAggrEpConsts()
    naming_props = set([])

    mo_meta = MoMeta("ComputeResourceAggrEp", "computeResourceAggrEp", "compute", VersionMeta.Version101a, "InputOutput", 0x1f, [], ["admin"], ['topRoot'], ['computeFaultUpgradeFlag', 'computeGroupMembership', 'computeProfile', 'computeResourceSetManager', 'computeSystem', 'faultGlobalSeverityHolder', 'faultGlobalTypedHolder'], ["Get", "Set"])

    prop_meta = {
        "available_physical_cnt": MoPropertyMeta("available_physical_cnt", "availablePhysicalCnt", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "polling_interval": MoPropertyMeta("polling_interval", "pollingInterval", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["10 min", "15 min", "20 min", "30 min", "45 min", "5 min", "60 min"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "total_physical_cnt": MoPropertyMeta("total_physical_cnt", "totalPhysicalCnt", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
    }

    prop_map = {
        "availablePhysicalCnt": "available_physical_cnt", 
        "childAction": "child_action", 
        "dn": "dn", 
        "pollingInterval": "polling_interval", 
        "rn": "rn", 
        "status": "status", 
        "totalPhysicalCnt": "total_physical_cnt", 
    }

    def __init__(self, **kwargs):
        self._dirty_mask = 0
        self.available_physical_cnt = None
        self.child_action = None
        self.polling_interval = None
        self.status = None
        self.total_physical_cnt = None

        ManagedObject.__init__(self, "ComputeResourceAggrEp", **kwargs)




"""This module contains the general information for CimcvmediaExtMgmtRuleEntry ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class CimcvmediaExtMgmtRuleEntryConsts():
    MOUNT_PROTOCOL_CIFS = "cifs"
    MOUNT_PROTOCOL_HTTP = "http"
    MOUNT_PROTOCOL_HTTPS = "https"
    MOUNT_PROTOCOL_NFS = "nfs"
    MOUNT_PROTOCOL_UNKNOWN = "unknown"


class CimcvmediaExtMgmtRuleEntry(ManagedObject):
    """This is CimcvmediaExtMgmtRuleEntry class."""

    consts = CimcvmediaExtMgmtRuleEntryConsts()
    naming_props = set(['mappingName'])

    mo_meta = MoMeta("CimcvmediaExtMgmtRuleEntry", "cimcvmediaExtMgmtRuleEntry", "ext-mgmt-rule-[mapping_name]", VersionMeta.Version121e, "InputOutput", 0x1f, [], ["read-only"], ['cimcvmediaActualMountList'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version121e, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version121e, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "ext_mgmt_ip_addr": MoPropertyMeta("ext_mgmt_ip_addr", "extMgmtIpAddr", "string", VersionMeta.Version121e, MoPropertyMeta.READ_ONLY, None, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []), 
        "mapping_name": MoPropertyMeta("mapping_name", "mappingName", "string", VersionMeta.Version121e, MoPropertyMeta.NAMING, 0x4, None, None, r"""[a-zA-Z0-9][a-zA-Z0-9_.:-]{0,63}""", [], []), 
        "mgmt_if_ip_addr": MoPropertyMeta("mgmt_if_ip_addr", "mgmtIfIpAddr", "string", VersionMeta.Version121e, MoPropertyMeta.READ_ONLY, None, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []), 
        "mount_protocol": MoPropertyMeta("mount_protocol", "mountProtocol", "string", VersionMeta.Version121e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["cifs", "http", "https", "nfs", "unknown"], []), 
        "remote_ip_addr": MoPropertyMeta("remote_ip_addr", "remoteIpAddr", "string", VersionMeta.Version121e, MoPropertyMeta.READ_ONLY, None, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []), 
        "remote_port": MoPropertyMeta("remote_port", "remotePort", "uint", VersionMeta.Version121e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version121e, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version121e, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "extMgmtIpAddr": "ext_mgmt_ip_addr", 
        "mappingName": "mapping_name", 
        "mgmtIfIpAddr": "mgmt_if_ip_addr", 
        "mountProtocol": "mount_protocol", 
        "remoteIpAddr": "remote_ip_addr", 
        "remotePort": "remote_port", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, mapping_name, **kwargs):
        self._dirty_mask = 0
        self.mapping_name = mapping_name
        self.child_action = None
        self.ext_mgmt_ip_addr = None
        self.mgmt_if_ip_addr = None
        self.mount_protocol = None
        self.remote_ip_addr = None
        self.remote_port = None
        self.status = None

        ManagedObject.__init__(self, "CimcvmediaExtMgmtRuleEntry", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ConfigFabricInterconnectItem ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ConfigFabricInterconnectItemConsts():
    DOMAIN_CONNECTION_STATE_CONNECTED = "connected"
    DOMAIN_CONNECTION_STATE_LOST_CONNECTIVITY = "lost-connectivity"
    DOMAIN_OPER_STATE_LOST_VISIBILITY = "lost-visibility"
    DOMAIN_OPER_STATE_REGISTERED = "registered"
    DOMAIN_OPER_STATE_REGISTERING = "registering"
    DOMAIN_OPER_STATE_SYNCHRONIZING = "synchronizing"
    DOMAIN_OPER_STATE_UNREGISTERED = "unregistered"
    DOMAIN_OPER_STATE_VERSION_MISMATCH = "version-mismatch"
    DOMAIN_SUSPEND_STATE_OFF = "off"
    DOMAIN_SUSPEND_STATE_ON = "on"
    FAULT_LEVEL_CLEARED = "cleared"
    FAULT_LEVEL_CONDITION = "condition"
    FAULT_LEVEL_CRITICAL = "critical"
    FAULT_LEVEL_INFO = "info"
    FAULT_LEVEL_MAJOR = "major"
    FAULT_LEVEL_MINOR = "minor"
    FAULT_LEVEL_WARNING = "warning"
    FW_OPER_STATE_ACTIVATING = "activating"
    FW_OPER_STATE_BAD_IMAGE = "bad-image"
    FW_OPER_STATE_FAILED = "failed"
    FW_OPER_STATE_PENDING_NEXT_BOOT = "pending-next-boot"
    FW_OPER_STATE_READY = "ready"
    FW_OPER_STATE_REBOOTING = "rebooting"
    FW_OPER_STATE_SCHEDULED = "scheduled"
    FW_OPER_STATE_SET_STARTUP = "set-startup"
    FW_OPER_STATE_THROTTLED = "throttled"
    FW_OPER_STATE_UPDATING = "updating"
    FW_OPER_STATE_UPGRADING = "upgrading"
    ID_A = "A"
    ID_B = "B"
    ID_NONE = "NONE"
    ID_MGMT = "mgmt"
    LOCATOR_LED_OPER_STATE_BLINKING = "blinking"
    LOCATOR_LED_OPER_STATE_ETH = "eth"
    LOCATOR_LED_OPER_STATE_FC = "fc"
    LOCATOR_LED_OPER_STATE_OFF = "off"
    LOCATOR_LED_OPER_STATE_ON = "on"
    LOCATOR_LED_OPER_STATE_UNKNOWN = "unknown"


class ConfigFabricInterconnectItem(ManagedObject):
    """This is ConfigFabricInterconnectItem class."""

    consts = ConfigFabricInterconnectItemConsts()
    naming_props = set([])

    mo_meta = MoMeta("ConfigFabricInterconnectItem", "configFabricInterconnectItem", "fabric-interconnect-item", VersionMeta.Version131a, "InputOutput", 0xf, [], ["read-only"], [], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "domain_connection_state": MoPropertyMeta("domain_connection_state", "domainConnectionState", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["connected", "lost-connectivity"], []), 
        "domain_dn": MoPropertyMeta("domain_dn", "domainDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "domain_group_dn": MoPropertyMeta("domain_group_dn", "domainGroupDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "domain_name": MoPropertyMeta("domain_name", "domainName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "domain_oper_state": MoPropertyMeta("domain_oper_state", "domainOperState", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["lost-visibility", "registered", "registering", "synchronizing", "unregistered", "version-mismatch"], []), 
        "domain_suspend_state": MoPropertyMeta("domain_suspend_state", "domainSuspendState", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["off", "on"], []), 
        "fabric_interconnect_dn": MoPropertyMeta("fabric_interconnect_dn", "fabricInterconnectDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "fault_level": MoPropertyMeta("fault_level", "faultLevel", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["cleared", "condition", "critical", "info", "major", "minor", "warning"], []), 
        "fw_oper_state": MoPropertyMeta("fw_oper_state", "fwOperState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["activating", "bad-image", "failed", "pending-next-boot", "ready", "rebooting", "scheduled", "set-startup", "throttled", "updating", "upgrading"], []), 
        "fw_service_pack_version": MoPropertyMeta("fw_service_pack_version", "fwServicePackVersion", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "fw_version": MoPropertyMeta("fw_version", "fwVersion", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "id": MoPropertyMeta("id", "id", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["A", "B", "NONE", "mgmt"], []), 
        "leadership": MoPropertyMeta("leadership", "leadership", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "locator_led_oper_state": MoPropertyMeta("locator_led_oper_state", "locatorLedOperState", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["blinking", "eth", "fc", "off", "on", "unknown"], []), 
        "model": MoPropertyMeta("model", "model", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "num_of_eth_ports": MoPropertyMeta("num_of_eth_ports", "numOfEthPorts", "uint", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "num_of_expansion_modules": MoPropertyMeta("num_of_expansion_modules", "numOfExpansionModules", "uint", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "num_of_fc_ports": MoPropertyMeta("num_of_fc_ports", "numOfFcPorts", "uint", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "num_of_fixed_modules": MoPropertyMeta("num_of_fixed_modules", "numOfFixedModules", "uint", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "oob_if_ip": MoPropertyMeta("oob_if_ip", "oobIfIp", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []), 
        "operability": MoPropertyMeta("operability", "operability", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "serial": MoPropertyMeta("serial", "serial", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "domainConnectionState": "domain_connection_state", 
        "domainDn": "domain_dn", 
        "domainGroupDn": "domain_group_dn", 
        "domainName": "domain_name", 
        "domainOperState": "domain_oper_state", 
        "domainSuspendState": "domain_suspend_state", 
        "fabricInterconnectDn": "fabric_interconnect_dn", 
        "faultLevel": "fault_level", 
        "fwOperState": "fw_oper_state", 
        "fwServicePackVersion": "fw_service_pack_version", 
        "fwVersion": "fw_version", 
        "id": "id", 
        "leadership": "leadership", 
        "locatorLedOperState": "locator_led_oper_state", 
        "model": "model", 
        "numOfEthPorts": "num_of_eth_ports", 
        "numOfExpansionModules": "num_of_expansion_modules", 
        "numOfFcPorts": "num_of_fc_ports", 
        "numOfFixedModules": "num_of_fixed_modules", 
        "oobIfIp": "oob_if_ip", 
        "operability": "operability", 
        "rn": "rn", 
        "serial": "serial", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.domain_connection_state = None
        self.domain_dn = None
        self.domain_group_dn = None
        self.domain_name = None
        self.domain_oper_state = None
        self.domain_suspend_state = None
        self.fabric_interconnect_dn = None
        self.fault_level = None
        self.fw_oper_state = None
        self.fw_service_pack_version = None
        self.fw_version = None
        self.id = None
        self.leadership = None
        self.locator_led_oper_state = None
        self.model = None
        self.num_of_eth_ports = None
        self.num_of_expansion_modules = None
        self.num_of_fc_ports = None
        self.num_of_fixed_modules = None
        self.oob_if_ip = None
        self.operability = None
        self.serial = None
        self.status = None

        ManagedObject.__init__(self, "ConfigFabricInterconnectItem", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ConfigSearchOptions ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ConfigSearchOptionsConsts():
    OBJECT_TYPE_AAA_EP_AUTH_PROFILE = "aaaEpAuthProfile"
    OBJECT_TYPE_ADAPTOR_HOST_ETH_IF_PROFILE = "adaptorHostEthIfProfile"
    OBJECT_TYPE_ADAPTOR_HOST_FC_IF_PROFILE = "adaptorHostFcIfProfile"
    OBJECT_TYPE_ADAPTOR_HOST_ISCSI_IF_PROFILE = "adaptorHostIscsiIfProfile"
    OBJECT_TYPE_BIOS_VPROFILE = "biosVProfile"
    OBJECT_TYPE_CALLHOME_EP = "callhomeEp"
    OBJECT_TYPE_COMM_CIMXML = "commCimxml"
    OBJECT_TYPE_COMM_DATE_TIME = "commDateTime"
    OBJECT_TYPE_COMM_DNS = "commDns"
    OBJECT_TYPE_COMM_HTTP = "commHttp"
    OBJECT_TYPE_COMM_SHELL_SVC_LIMITS = "commShellSvcLimits"
    OBJECT_TYPE_COMM_SNMP = "commSnmp"
    OBJECT_TYPE_COMM_SYSLOG = "commSyslog"
    OBJECT_TYPE_COMM_TELNET = "commTelnet"
    OBJECT_TYPE_COMM_WEB_SVC_LIMITS = "commWebSvcLimits"
    OBJECT_TYPE_COMPUTE_GRAPHICS_CARD_POLICY = "computeGraphicsCardPolicy"
    OBJECT_TYPE_COMPUTE_MODULAR_CHASSIS_FAN_POLICY = "computeModularChassisFanPolicy"
    OBJECT_TYPE_COMPUTE_POOLING_POLICY = "computePoolingPolicy"
    OBJECT_TYPE_COMPUTE_POWER_EXTENDED_POLICY = "computePowerExtendedPolicy"
    OBJECT_TYPE_COMPUTE_POWER_SAVE_POLICY = "computePowerSavePolicy"
    OBJECT_TYPE_COMPUTE_POWER_SYNC_POLICY = "computePowerSyncPolicy"
    OBJECT_TYPE_COMPUTE_PSU_POLICY = "computePsuPolicy"
    OBJECT_TYPE_COMPUTE_QUAL = "computeQual"
    OBJECT_TYPE_COMPUTE_SCRUB_POLICY = "computeScrubPolicy"
    OBJECT_TYPE_CPMAINT_MAINT_POLICY = "cpmaintMaintPolicy"
    OBJECT_TYPE_DIAG_RUN_POLICY = "diagRunPolicy"
    OBJECT_TYPE_EPQOS_DEFINITION = "epqosDefinition"
    OBJECT_TYPE_EQUIPMENT_COMPUTE_CONN_POLICY_NAME = "equipmentComputeConnPolicyName"
    OBJECT_TYPE_EXTMGMT_IF_MON_POLICY = "extmgmtIfMonPolicy"
    OBJECT_TYPE_FABRIC_MULTICAST_POLICY = "fabricMulticastPolicy"
    OBJECT_TYPE_FABRIC_VCON_PROFILE = "fabricVConProfile"
    OBJECT_TYPE_FABRIC_VLAN = "fabricVlan"
    OBJECT_TYPE_FABRIC_VSAN = "fabricVsan"
    OBJECT_TYPE_FAULT_POLICY = "faultPolicy"
    OBJECT_TYPE_FCPOOL_INITIATORS = "fcpoolInitiators"
    OBJECT_TYPE_FIRMWARE_CHASSIS_PACK = "firmwareChassisPack"
    OBJECT_TYPE_FIRMWARE_COMPUTE_HOST_PACK = "firmwareComputeHostPack"
    OBJECT_TYPE_IPPOOL_POOL = "ippoolPool"
    OBJECT_TYPE_IQNPOOL_POOL = "iqnpoolPool"
    OBJECT_TYPE_ISCSI_AUTH_PROFILE = "iscsiAuthProfile"
    OBJECT_TYPE_LS_SERVER = "lsServer"
    OBJECT_TYPE_LSBOOT_POLICY = "lsbootPolicy"
    OBJECT_TYPE_LSMAINT_MAINT_POLICY = "lsmaintMaintPolicy"
    OBJECT_TYPE_LSTORAGE_DISK_GROUP_CONFIG_POLICY = "lstorageDiskGroupConfigPolicy"
    OBJECT_TYPE_LSTORAGE_DISK_ZONING_POLICY = "lstorageDiskZoningPolicy"
    OBJECT_TYPE_LSTORAGE_PROFILE = "lstorageProfile"
    OBJECT_TYPE_MACPOOL_POOL = "macpoolPool"
    OBJECT_TYPE_NWCTRL_DEFINITION = "nwctrlDefinition"
    OBJECT_TYPE_POWER_MGMT_POLICY = "powerMgmtPolicy"
    OBJECT_TYPE_POWER_POLICY = "powerPolicy"
    OBJECT_TYPE_SOL_POLICY = "solPolicy"
    OBJECT_TYPE_STATS_THRESHOLD_POLICY = "statsThresholdPolicy"
    OBJECT_TYPE_STORAGE_CONNECTION_POLICY = "storageConnectionPolicy"
    OBJECT_TYPE_STORAGE_LOCAL_DISK_CONFIG_POLICY = "storageLocalDiskConfigPolicy"
    OBJECT_TYPE_SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET = "sysdebugAutoCoreFileExportTarget"
    OBJECT_TYPE_SYSDEBUG_MEP_LOG_POLICY = "sysdebugMEpLogPolicy"
    OBJECT_TYPE_TRIG_SCHED = "trigSched"
    OBJECT_TYPE_UNSPECIFIED = "unspecified"
    OBJECT_TYPE_UUIDPOOL_POOL = "uuidpoolPool"
    OBJECT_TYPE_VNIC_DYNAMIC_CON_POLICY = "vnicDynamicConPolicy"
    OBJECT_TYPE_VNIC_LAN_CONN_POLICY = "vnicLanConnPolicy"
    OBJECT_TYPE_VNIC_LAN_CONN_TEMPL = "vnicLanConnTempl"
    OBJECT_TYPE_VNIC_SAN_CONN_POLICY = "vnicSanConnPolicy"
    OBJECT_TYPE_VNIC_SAN_CONN_TEMPL = "vnicSanConnTempl"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    POLICY_OWNER_UNSPECIFIED = "unspecified"
    SEARCH_TYPE_CONTAINS = "contains"
    SEARCH_TYPE_EXACT_MATCH = "exactMatch"
    SEARCH_TYPE_STARTS_WITH = "startsWith"


class ConfigSearchOptions(ManagedObject):
    """This is ConfigSearchOptions class."""

    consts = ConfigSearchOptionsConsts()
    naming_props = set([])

    mo_meta = MoMeta("ConfigSearchOptions", "configSearchOptions", "", VersionMeta.Version112a, "InputOutput", 0xf, [], ["read-only"], [], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version112a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "object_type": MoPropertyMeta("object_type", "objectType", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["aaaEpAuthProfile", "adaptorHostEthIfProfile", "adaptorHostFcIfProfile", "adaptorHostIscsiIfProfile", "biosVProfile", "callhomeEp", "commCimxml", "commDateTime", "commDns", "commHttp", "commShellSvcLimits", "commSnmp", "commSyslog", "commTelnet", "commWebSvcLimits", "computeGraphicsCardPolicy", "computeModularChassisFanPolicy", "computePoolingPolicy", "computePowerExtendedPolicy", "computePowerSavePolicy", "computePowerSyncPolicy", "computePsuPolicy", "computeQual", "computeScrubPolicy", "cpmaintMaintPolicy", "diagRunPolicy", "epqosDefinition", "equipmentComputeConnPolicyName", "extmgmtIfMonPolicy", "fabricMulticastPolicy", "fabricVConProfile", "fabricVlan", "fabricVsan", "faultPolicy", "fcpoolInitiators", "firmwareChassisPack", "firmwareComputeHostPack", "ippoolPool", "iqnpoolPool", "iscsiAuthProfile", "lsServer", "lsbootPolicy", "lsmaintMaintPolicy", "lstorageDiskGroupConfigPolicy", "lstorageDiskZoningPolicy", "lstorageProfile", "macpoolPool", "nwctrlDefinition", "powerMgmtPolicy", "powerPolicy", "solPolicy", "statsThresholdPolicy", "storageConnectionPolicy", "storageLocalDiskConfigPolicy", "sysdebugAutoCoreFileExportTarget", "sysdebugMEpLogPolicy", "trigSched", "unspecified", "uuidpoolPool", "vnicDynamicConPolicy", "vnicLanConnPolicy", "vnicLanConnTempl", "vnicSanConnPolicy", "vnicSanConnTempl"], []), 
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["local", "pending-policy", "policy", "unspecified"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "search_type": MoPropertyMeta("search_type", "searchType", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["contains", "exactMatch", "startsWith"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "objectType": "object_type", 
        "policyOwner": "policy_owner", 
        "rn": "rn", 
        "searchType": "search_type", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.object_type = None
        self.policy_owner = None
        self.search_type = None
        self.status = None

        ManagedObject.__init__(self, "ConfigSearchOptions", parent_mo_or_dn, **kwargs)




"""This module contains the general information for EquipmentFruVariant ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class EquipmentFruVariantConsts():
    pass


class EquipmentFruVariant(ManagedObject):
    """This is EquipmentFruVariant class."""

    consts = EquipmentFruVariantConsts()
    naming_props = set(['type'])

    mo_meta = MoMeta("EquipmentFruVariant", "equipmentFruVariant", "fruVariant-[type]", VersionMeta.Version201b, "InputOutput", 0x1f, [], [""], ['adaptorFruCapProvider', 'diagSrvCapProvider', 'equipmentBladeCapProvider', 'equipmentChassisCapProvider', 'equipmentCrossFabricModuleCapProvider', 'equipmentFanModuleCapProvider', 'equipmentFexCapProvider', 'equipmentGemCapProvider', 'equipmentGraphicsCardCapProvider', 'equipmentHostIfCapProvider', 'equipmentIOCardCapProvider', 'equipmentLocalDiskCapProvider', 'equipmentLocalDiskControllerCapProvider', 'equipmentMemoryUnitCapProvider', 'equipmentPcieConnectorCapProvider', 'equipmentPcieNodeCapProvider', 'equipmentProcessorUnitCapProvider', 'equipmentPsuCapProvider', 'equipmentRackUnitCapProvider', 'equipmentServerUnitCapProvider', 'equipmentSwitchCapProvider', 'equipmentSwitchIOCardCapProvider', 'equipmentSystemFruCapProvider'], [], ["get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201b, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "description": MoPropertyMeta("description", "description", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "pid": MoPropertyMeta("pid", "pid", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version201b, MoPropertyMeta.NAMING, 0x10, 1, 510, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "description": "description", 
        "dn": "dn", 
        "pid": "pid", 
        "rn": "rn", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, type, **kwargs):
        self._dirty_mask = 0
        self.type = type
        self.child_action = None
        self.description = None
        self.pid = None
        self.status = None

        ManagedObject.__init__(self, "EquipmentFruVariant", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ConfigDomainFilter ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ConfigDomainFilterConsts():
    CONNECTION_STATE_CONNECTED = "connected"
    CONNECTION_STATE_LOST_CONNECTIVITY = "lost-connectivity"
    FAULT_LEVEL_CLEARED = "cleared"
    FAULT_LEVEL_CONDITION = "condition"
    FAULT_LEVEL_CRITICAL = "critical"
    FAULT_LEVEL_INFO = "info"
    FAULT_LEVEL_MAJOR = "major"
    FAULT_LEVEL_MINOR = "minor"
    FAULT_LEVEL_WARNING = "warning"
    FW_OPER_STATE_FAILED = "failed"
    FW_OPER_STATE_IN_PROGRESS = "in-progress"
    FW_OPER_STATE_PENDING_USER_ACK = "pending-user-ack"
    FW_OPER_STATE_READY = "ready"
    FW_OPER_STATE_SCHEDULED = "scheduled"
    FW_OPER_STATE_START_PENDING_EXT_PERMISSION = "start-pending-ext-permission"
    INVENTORY_STATUS_IN_PROGRESS = "in-progress"
    INVENTORY_STATUS_OK = "ok"
    INVENTORY_STATUS_THROTTLED = "throttled"
    LIC_STATE_LICENSE_EXPIRED = "license-expired"
    LIC_STATE_LICENSE_GRACEPERIOD = "license-graceperiod"
    LIC_STATE_LICENSE_INSUFFICIENT = "license-insufficient"
    LIC_STATE_LICENSE_OK = "license-ok"
    LIC_STATE_NOT_APPLICABLE = "not-applicable"
    LIC_STATE_UNKNOWN = "unknown"
    OPER_STATE_LOST_VISIBILITY = "lost-visibility"
    OPER_STATE_REGISTERED = "registered"
    OPER_STATE_REGISTERING = "registering"
    OPER_STATE_SYNCHRONIZING = "synchronizing"
    OPER_STATE_UNREGISTERED = "unregistered"
    OPER_STATE_VERSION_MISMATCH = "version-mismatch"
    PRODUCT_FAMILY_UCS_CLASSIC = "ucs-classic"
    PRODUCT_FAMILY_UCS_CLASSIC_3GEN = "ucs-classic-3gen"
    PRODUCT_FAMILY_UCS_CLASSIC_4GEN = "ucs-classic-4gen"
    PRODUCT_FAMILY_UCS_CLASSIC_5GEN = "ucs-classic-5gen"
    PRODUCT_FAMILY_UCS_MINI = "ucs-mini"
    PRODUCT_FAMILY_UCS_X_SERIES_DIRECT = "ucs-x-series-direct"
    SUSPEND_STATE_OFF = "off"
    SUSPEND_STATE_ON = "on"


class ConfigDomainFilter(ManagedObject):
    """This is ConfigDomainFilter class."""

    consts = ConfigDomainFilterConsts()
    naming_props = set([])

    mo_meta = MoMeta("ConfigDomainFilter", "configDomainFilter", "domain-filter", VersionMeta.Version131a, "InputOutput", 0x7fff, [], ["read-only"], [], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "connection_state": MoPropertyMeta("connection_state", "connectionState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["connected", "lost-connectivity"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "domain_group_dn": MoPropertyMeta("domain_group_dn", "domainGroupDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x8, 0, 256, None, [], []), 
        "fault_level": MoPropertyMeta("fault_level", "faultLevel", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["cleared", "condition", "critical", "info", "major", "minor", "warning"], []), 
        "fw_oper_state": MoPropertyMeta("fw_oper_state", "fwOperState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["failed", "in-progress", "pending-user-ack", "ready", "scheduled", "start-pending-ext-permission"], []), 
        "fw_package_version": MoPropertyMeta("fw_package_version", "fwPackageVersion", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x40, 0, 510, None, [], []), 
        "fw_service_pack_version": MoPropertyMeta("fw_service_pack_version", "fwServicePackVersion", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x80, 0, 510, None, [], []), 
        "inventory_status": MoPropertyMeta("inventory_status", "inventoryStatus", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, ["in-progress", "ok", "throttled"], []), 
        "lic_state": MoPropertyMeta("lic_state", "licState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, ["license-expired", "license-graceperiod", "license-insufficient", "license-ok", "not-applicable", "unknown"], []), 
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x400, None, None, None, ["lost-visibility", "registered", "registering", "synchronizing", "unregistered", "version-mismatch"], []), 
        "product_family": MoPropertyMeta("product_family", "productFamily", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x800, None, None, None, ["ucs-classic", "ucs-classic-3gen", "ucs-classic-4gen", "ucs-classic-5gen", "ucs-mini", "ucs-x-series-direct"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x1000, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x2000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "suspend_state": MoPropertyMeta("suspend_state", "suspendState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x4000, None, None, None, ["off", "on"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "connectionState": "connection_state", 
        "dn": "dn", 
        "domainGroupDn": "domain_group_dn", 
        "faultLevel": "fault_level", 
        "fwOperState": "fw_oper_state", 
        "fwPackageVersion": "fw_package_version", 
        "fwServicePackVersion": "fw_service_pack_version", 
        "inventoryStatus": "inventory_status", 
        "licState": "lic_state", 
        "operState": "oper_state", 
        "productFamily": "product_family", 
        "rn": "rn", 
        "status": "status", 
        "suspendState": "suspend_state", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.connection_state = None
        self.domain_group_dn = None
        self.fault_level = None
        self.fw_oper_state = None
        self.fw_package_version = None
        self.fw_service_pack_version = None
        self.inventory_status = None
        self.lic_state = None
        self.oper_state = None
        self.product_family = None
        self.status = None
        self.suspend_state = None

        ManagedObject.__init__(self, "ConfigDomainFilter", parent_mo_or_dn, **kwargs)




"""This module contains the general information for CimcvmediaConfigMountEntry ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class CimcvmediaConfigMountEntryConsts():
    AUTH_OPTION_DEFAULT = "default"
    AUTH_OPTION_NONE = "none"
    AUTH_OPTION_NTLM = "ntlm"
    AUTH_OPTION_NTLMI = "ntlmi"
    AUTH_OPTION_NTLMSSP = "ntlmssp"
    AUTH_OPTION_NTLMSSPI = "ntlmsspi"
    AUTH_OPTION_NTLMV2 = "ntlmv2"
    AUTH_OPTION_NTLMV2I = "ntlmv2i"
    DEVICE_TYPE_CDD = "cdd"
    DEVICE_TYPE_HDD = "hdd"
    DEVICE_TYPE_UNKNOWN = "unknown"
    IMAGE_NAME_VARIABLE_NONE = "none"
    IMAGE_NAME_VARIABLE_SERVICE_PROFILE_NAME = "service-profile-name"
    MOUNT_PROTOCOL_CIFS = "cifs"
    MOUNT_PROTOCOL_HTTP = "http"
    MOUNT_PROTOCOL_HTTPS = "https"
    MOUNT_PROTOCOL_NFS = "nfs"
    MOUNT_PROTOCOL_UNKNOWN = "unknown"
    PWD_SET_FALSE = "false"
    PWD_SET_NO = "no"
    PWD_SET_TRUE = "true"
    PWD_SET_YES = "yes"


class CimcvmediaConfigMountEntry(ManagedObject):
    """This is CimcvmediaConfigMountEntry class."""

    consts = CimcvmediaConfigMountEntryConsts()
    naming_props = set(['mappingName'])

    mo_meta = MoMeta("CimcvmediaConfigMountEntry", "cimcvmediaConfigMountEntry", "cfg-mnt-entry-[mapping_name]", VersionMeta.Version121e, "InputOutput", 0x1ffff, [], ["admin", "ls-compute", "ls-config", "ls-config-policy", "ls-server", "ls-server-policy", "ls-storage", "ls-storage-policy"], ['cimcvmediaMountConfigDef', 'cimcvmediaMountConfigPolicy'], [], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "auth_option": MoPropertyMeta("auth_option", "authOption", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["default", "none", "ntlm", "ntlmi", "ntlmssp", "ntlmsspi", "ntlmv2", "ntlmv2i"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version121e, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "description": MoPropertyMeta("description", "description", "string", VersionMeta.Version121e, MoPropertyMeta.READ_WRITE, 0x4, 0, 510, None, [], []), 
        "device_type": MoPropertyMeta("device_type", "deviceType", "string", VersionMeta.Version121e, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["cdd", "hdd", "unknown"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version121e, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "enc_pwd": MoPropertyMeta("enc_pwd", "encPwd", "string", VersionMeta.Version121e, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "image_file_name": MoPropertyMeta("image_file_name", "imageFileName", "string", VersionMeta.Version121e, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, [], []), 
        "image_name_variable": MoPropertyMeta("image_name_variable", "imageNameVariable", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["none", "service-profile-name"], []), 
        "image_path": MoPropertyMeta("image_path", "imagePath", "string", VersionMeta.Version121e, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, [], []), 
        "mapping_name": MoPropertyMeta("mapping_name", "mappingName", "string", VersionMeta.Version121e, MoPropertyMeta.NAMING, 0x100, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []), 
        "mount_protocol": MoPropertyMeta("mount_protocol", "mountProtocol", "string", VersionMeta.Version121e, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, ["cifs", "http", "https", "nfs", "unknown"], []), 
        "password": MoPropertyMeta("password", "password", "string", VersionMeta.Version121e, MoPropertyMeta.READ_WRITE, 0x400, None, None, r"""[!""#%&'\(\)\*\+,\-\./:;<>@\[\\\]\^_`\{\|\}~a-zA-Z0-9]{0,128}""", [], []), 
        "pwd_set": MoPropertyMeta("pwd_set", "pwdSet", "string", VersionMeta.Version121e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "remote_host": MoPropertyMeta("remote_host", "remoteHost", "string", VersionMeta.Version121e, MoPropertyMeta.READ_WRITE, 0x800, None, None, r"""^[A-Za-z]([A-Za-z0-9_.-]*[A-Za-z0-9])?([A-Za-z]([A-Za-z0-9._-]*[A-Za-z0-9])?)*$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])$|^([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}$|^([0-9a-fA-F]{1,4}:){1,7}:$|^([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}$|^([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}$|^([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}$|^([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}$|^([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}$|^[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})$|^:((:[0-9a-fA-F]{1,4}){1,7}|:)$""", [], []), 
        "remote_ip_address": MoPropertyMeta("remote_ip_address", "remoteIpAddress", "string", VersionMeta.Version121e, MoPropertyMeta.READ_WRITE, 0x1000, None, None, r"""^[A-Za-z]([A-Za-z0-9_.-]*[A-Za-z0-9])?([A-Za-z]([A-Za-z0-9._-]*[A-Za-z0-9])?)*$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])$|^([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}$|^([0-9a-fA-F]{1,4}:){1,7}:$|^([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}$|^([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}$|^([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}$|^([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}$|^([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}$|^[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})$|^:((:[0-9a-fA-F]{1,4}){1,7}|:)$""", [], []), 
        "remote_port": MoPropertyMeta("remote_port", "remotePort", "uint", VersionMeta.Version121e, MoPropertyMeta.READ_WRITE, 0x2000, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version121e, MoPropertyMeta.READ_ONLY, 0x4000, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version121e, MoPropertyMeta.READ_WRITE, 0x8000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "user_id": MoPropertyMeta("user_id", "userId", "string", VersionMeta.Version121e, MoPropertyMeta.READ_WRITE, 0x10000, 0, 63, None, [], []), 
    }

    prop_map = {
        "authOption": "auth_option", 
        "childAction": "child_action", 
        "description": "description", 
        "deviceType": "device_type", 
        "dn": "dn", 
        "encPwd": "enc_pwd", 
        "imageFileName": "image_file_name", 
        "imageNameVariable": "image_name_variable", 
        "imagePath": "image_path", 
        "mappingName": "mapping_name", 
        "mountProtocol": "mount_protocol", 
        "password": "password", 
        "pwdSet": "pwd_set", 
        "remoteHost": "remote_host", 
        "remoteIpAddress": "remote_ip_address", 
        "remotePort": "remote_port", 
        "rn": "rn", 
        "status": "status", 
        "userId": "user_id", 
    }

    def __init__(self, parent_mo_or_dn, mapping_name, **kwargs):
        self._dirty_mask = 0
        self.mapping_name = mapping_name
        self.auth_option = None
        self.child_action = None
        self.description = None
        self.device_type = None
        self.enc_pwd = None
        self.image_file_name = None
        self.image_name_variable = None
        self.image_path = None
        self.mount_protocol = None
        self.password = None
        self.pwd_set = None
        self.remote_host = None
        self.remote_ip_address = None
        self.remote_port = None
        self.status = None
        self.user_id = None

        ManagedObject.__init__(self, "CimcvmediaConfigMountEntry", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ComputeChassisDiscPolicy ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ComputeChassisDiscPolicyConsts():
    ACTION_1_LINK = "1-link"
    ACTION_2_LINK = "2-link"
    ACTION_4_LINK = "4-link"
    ACTION_8_LINK = "8-link"
    ACTION_IMMEDIATE = "immediate"
    ACTION_PLATFORM_MAX = "platform-max"
    ACTION_USER_ACKNOWLEDGED = "user-acknowledged"
    BACKPLANE_SPEED_PREF_40_G = "40G"
    BACKPLANE_SPEED_PREF_4X10_G = "4x10G"
    INT_ID_NONE = "none"
    LINK_AGGREGATION_PREF_NONE = "none"
    LINK_AGGREGATION_PREF_PORT_CHANNEL = "port-channel"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    POLICY_OWNER_UNSPECIFIED = "unspecified"
    REBALANCE_IMMEDIATE = "immediate"
    REBALANCE_USER_ACKNOWLEDGED = "user-acknowledged"


class ComputeChassisDiscPolicy(ManagedObject):
    """This is ComputeChassisDiscPolicy class."""

    consts = ComputeChassisDiscPolicyConsts()
    naming_props = set([])

    mo_meta = MoMeta("ComputeChassisDiscPolicy", "computeChassisDiscPolicy", "chassis-discovery", VersionMeta.Version101a, "InputOutput", 0x7ff, [], ["admin", "domain-group-management", "pn-policy"], ['orgDomainGroup', 'orgOrg'], [], ["Get", "Set"])

    prop_meta = {
        "action": MoPropertyMeta("action", "action", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["1-link", "2-link", "4-link", "8-link", "immediate", "platform-max", "user-acknowledged"], []), 
        "backplane_speed_pref": MoPropertyMeta("backplane_speed_pref", "backplaneSpeedPref", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["40G", "4x10G"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]), 
        "link_aggregation_pref": MoPropertyMeta("link_aggregation_pref", "linkAggregationPref", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["none", "port-channel"], []), 
        "multicast_hw_hash": MoPropertyMeta("multicast_hw_hash", "multicastHwHash", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, [], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["local", "pending-policy", "policy", "unspecified"], []), 
        "qualifier": MoPropertyMeta("qualifier", "qualifier", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "rebalance": MoPropertyMeta("rebalance", "rebalance", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, ["immediate", "user-acknowledged"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x200, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x400, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "action": "action", 
        "backplaneSpeedPref": "backplane_speed_pref", 
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "intId": "int_id", 
        "linkAggregationPref": "link_aggregation_pref", 
        "multicastHwHash": "multicast_hw_hash", 
        "name": "name", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "qualifier": "qualifier", 
        "rebalance": "rebalance", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.action = None
        self.backplane_speed_pref = None
        self.child_action = None
        self.descr = None
        self.int_id = None
        self.link_aggregation_pref = None
        self.multicast_hw_hash = None
        self.name = None
        self.policy_level = None
        self.policy_owner = None
        self.qualifier = None
        self.rebalance = None
        self.status = None

        ManagedObject.__init__(self, "ComputeChassisDiscPolicy", parent_mo_or_dn, **kwargs)




"""This module contains the meta information of ConfigSendAppImpactResponse ExternalMethod."""

from ..ucsccoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ConfigSendAppImpactResponse", "configSendAppImpactResponse", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_app_impact_response_set": MethodPropertyMeta("InAppImpactResponseSet", "inAppImpactResponseSet", "ConfigSet", "Version142b", "Input", True),
}

prop_map = {
    "cookie": "cookie",
    "inAppImpactResponseSet": "in_app_impact_response_set",
}




"""This module contains the general information for FaultGlobalTypedHolder ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FaultGlobalTypedHolderConsts():
    pass


class FaultGlobalTypedHolder(ManagedObject):
    """This is FaultGlobalTypedHolder class."""

    consts = FaultGlobalTypedHolderConsts()
    naming_props = set(['type'])

    mo_meta = MoMeta("FaultGlobalTypedHolder", "faultGlobalTypedHolder", "type-[type]", VersionMeta.Version101a, "InputOutput", 0x3f, [], ["admin"], ['computeResourceAggrEp'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "critical_cnt": MoPropertyMeta("critical_cnt", "criticalCnt", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "major_cnt": MoPropertyMeta("major_cnt", "majorCnt", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "minor_cnt": MoPropertyMeta("minor_cnt", "minorCnt", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x20, 1, 510, None, [], []), 
        "warning_cnt": MoPropertyMeta("warning_cnt", "warningCnt", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "criticalCnt": "critical_cnt", 
        "dn": "dn", 
        "majorCnt": "major_cnt", 
        "minorCnt": "minor_cnt", 
        "name": "name", 
        "rn": "rn", 
        "status": "status", 
        "type": "type", 
        "warningCnt": "warning_cnt", 
    }

    def __init__(self, parent_mo_or_dn, type, **kwargs):
        self._dirty_mask = 0
        self.type = type
        self.child_action = None
        self.critical_cnt = None
        self.major_cnt = None
        self.minor_cnt = None
        self.name = None
        self.status = None
        self.warning_cnt = None

        ManagedObject.__init__(self, "FaultGlobalTypedHolder", parent_mo_or_dn, **kwargs)




"""This module contains the general information for AdaptorEthOffloadProfile ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class AdaptorEthOffloadProfileConsts():
    pass


class AdaptorEthOffloadProfile(ManagedObject):
    """This is AdaptorEthOffloadProfile class."""

    consts = AdaptorEthOffloadProfileConsts()
    naming_props = set([])

    mo_meta = MoMeta("AdaptorEthOffloadProfile", "adaptorEthOffloadProfile", "eth-offload", VersionMeta.Version111a, "InputOutput", 0xff, [], ["admin", "ls-config-policy", "ls-network", "ls-server-policy"], ['adaptorHostEthIfProfile', 'adaptorUsnicConnDef'], [], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "large_receive": MoPropertyMeta("large_receive", "largeReceive", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "tcp_rx_checksum": MoPropertyMeta("tcp_rx_checksum", "tcpRxChecksum", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, [], []), 
        "tcp_segment": MoPropertyMeta("tcp_segment", "tcpSegment", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, [], []), 
        "tcp_tx_checksum": MoPropertyMeta("tcp_tx_checksum", "tcpTxChecksum", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "largeReceive": "large_receive", 
        "rn": "rn", 
        "status": "status", 
        "tcpRxChecksum": "tcp_rx_checksum", 
        "tcpSegment": "tcp_segment", 
        "tcpTxChecksum": "tcp_tx_checksum", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.large_receive = None
        self.status = None
        self.tcp_rx_checksum = None
        self.tcp_segment = None
        self.tcp_tx_checksum = None

        ManagedObject.__init__(self, "AdaptorEthOffloadProfile", parent_mo_or_dn, **kwargs)




"""This module contains the meta information of ConfigResolveClasses ExternalMethod."""

from ..ucsccoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ConfigResolveClasses", "configResolveClasses", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_hierarchical": MethodPropertyMeta("InHierarchical", "inHierarchical", "Xs:string", "Version142b", "Input", False),
    "in_ids": MethodPropertyMeta("InIds", "inIds", "ClassIdSet", "Version142b", "Input", True),
    "in_return_count_only": MethodPropertyMeta("InReturnCountOnly", "inReturnCountOnly", "Xs:string", "Version142b", "Input", False),
    "out_configs": MethodPropertyMeta("OutConfigs", "outConfigs", "ConfigSet", "Version142b", "Output", True),
    "out_count": MethodPropertyMeta("OutCount", "outCount", "Xs:unsignedInt", "Version142b", "Output", False),
}

prop_map = {
    "cookie": "cookie",
    "inHierarchical": "in_hierarchical",
    "inIds": "in_ids",
    "inReturnCountOnly": "in_return_count_only",
    "outConfigs": "out_configs",
    "outCount": "out_count",
}




"""This module contains the general information for SmartcallhomePeriodicInventoryStatus ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class SmartcallhomePeriodicInventoryStatusConsts():
    NEXT_DEADLINE_NEVER = "never"
    TIME_OF_LAST_SUCCESS_NEVER = "never"


class SmartcallhomePeriodicInventoryStatus(ManagedObject):
    """This is SmartcallhomePeriodicInventoryStatus class."""

    consts = SmartcallhomePeriodicInventoryStatusConsts()
    naming_props = set([])

    mo_meta = MoMeta("SmartcallhomePeriodicInventoryStatus", "smartcallhomePeriodicInventoryStatus", "inventory-status", VersionMeta.Version141a, "InputOutput", 0xf, [], ["read-only"], ['callhomeHolder'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "last_deadline": MoPropertyMeta("last_deadline", "lastDeadline", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "next_deadline": MoPropertyMeta("next_deadline", "nextDeadline", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", ["never"], []), 
        "retry_count": MoPropertyMeta("retry_count", "retryCount", "uint", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "time_of_last_attempt": MoPropertyMeta("time_of_last_attempt", "timeOfLastAttempt", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "time_of_last_success": MoPropertyMeta("time_of_last_success", "timeOfLastSuccess", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", ["never"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "lastDeadline": "last_deadline", 
        "nextDeadline": "next_deadline", 
        "retryCount": "retry_count", 
        "rn": "rn", 
        "status": "status", 
        "timeOfLastAttempt": "time_of_last_attempt", 
        "timeOfLastSuccess": "time_of_last_success", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.last_deadline = None
        self.next_deadline = None
        self.retry_count = None
        self.status = None
        self.time_of_last_attempt = None
        self.time_of_last_success = None

        ManagedObject.__init__(self, "SmartcallhomePeriodicInventoryStatus", parent_mo_or_dn, **kwargs)




"""This module contains the general information for AdaptorMenloQStats ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class AdaptorMenloQStatsConsts():
    MENLO_QUEUE_COMPONENT_N = "N"
    MENLO_QUEUE_COMPONENT_CPU = "cpu"
    MENLO_QUEUE_COMPONENT_ETH = "eth"
    MENLO_QUEUE_COMPONENT_FC = "fc"
    MENLO_QUEUE_COMPONENT_UNKNOWN = "unknown"
    MENLO_QUEUE_INDEX_0 = "0"
    MENLO_QUEUE_INDEX_0_A = "0_A"
    MENLO_QUEUE_INDEX_0_B = "0_B"
    MENLO_QUEUE_INDEX_1 = "1"
    MENLO_QUEUE_INDEX_1_A = "1_A"
    MENLO_QUEUE_INDEX_1_B = "1_B"
    MENLO_QUEUE_INDEX_UNKNOWN = "unknown"
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class AdaptorMenloQStats(ManagedObject):
    """This is AdaptorMenloQStats class."""

    consts = AdaptorMenloQStatsConsts()
    naming_props = set(['menloQueueComponent', 'menloQueueIndex'])

    mo_meta = MoMeta("AdaptorMenloQStats", "adaptorMenloQStats", "menlo-q-stats-comp-[menlo_queue_component]index-[menlo_queue_index]", VersionMeta.Version111a, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], ['adaptorUnit'], ['adaptorMenloQStatsHist'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "drop_overrun_n0": MoPropertyMeta("drop_overrun_n0", "dropOverrunN0", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_overrun_n0_delta": MoPropertyMeta("drop_overrun_n0_delta", "dropOverrunN0Delta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_overrun_n0_delta_avg": MoPropertyMeta("drop_overrun_n0_delta_avg", "dropOverrunN0DeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_overrun_n0_delta_max": MoPropertyMeta("drop_overrun_n0_delta_max", "dropOverrunN0DeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_overrun_n0_delta_min": MoPropertyMeta("drop_overrun_n0_delta_min", "dropOverrunN0DeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_overrun_n1": MoPropertyMeta("drop_overrun_n1", "dropOverrunN1", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_overrun_n1_delta": MoPropertyMeta("drop_overrun_n1_delta", "dropOverrunN1Delta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_overrun_n1_delta_avg": MoPropertyMeta("drop_overrun_n1_delta_avg", "dropOverrunN1DeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_overrun_n1_delta_max": MoPropertyMeta("drop_overrun_n1_delta_max", "dropOverrunN1DeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_overrun_n1_delta_min": MoPropertyMeta("drop_overrun_n1_delta_min", "dropOverrunN1DeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "menlo_queue_component": MoPropertyMeta("menlo_queue_component", "menloQueueComponent", "string", VersionMeta.Version111a, MoPropertyMeta.NAMING, None, None, None, None, ["N", "cpu", "eth", "fc", "unknown"], []), 
        "menlo_queue_index": MoPropertyMeta("menlo_queue_index", "menloQueueIndex", "string", VersionMeta.Version111a, MoPropertyMeta.NAMING, None, None, None, None, ["0", "0_A", "0_B", "1", "1_A", "1_B", "unknown"], []), 
        "normalized_time_col": MoPropertyMeta("normalized_time_col", "normalizedTimeCol", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "stats_reported": MoPropertyMeta("stats_reported", "statsReported", "int", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "truncate_overrun_n0": MoPropertyMeta("truncate_overrun_n0", "truncateOverrunN0", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "truncate_overrun_n0_delta": MoPropertyMeta("truncate_overrun_n0_delta", "truncateOverrunN0Delta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "truncate_overrun_n0_delta_avg": MoPropertyMeta("truncate_overrun_n0_delta_avg", "truncateOverrunN0DeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "truncate_overrun_n0_delta_max": MoPropertyMeta("truncate_overrun_n0_delta_max", "truncateOverrunN0DeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "truncate_overrun_n0_delta_min": MoPropertyMeta("truncate_overrun_n0_delta_min", "truncateOverrunN0DeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "truncate_overrun_n1": MoPropertyMeta("truncate_overrun_n1", "truncateOverrunN1", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "truncate_overrun_n1_delta": MoPropertyMeta("truncate_overrun_n1_delta", "truncateOverrunN1Delta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "truncate_overrun_n1_delta_avg": MoPropertyMeta("truncate_overrun_n1_delta_avg", "truncateOverrunN1DeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "truncate_overrun_n1_delta_max": MoPropertyMeta("truncate_overrun_n1_delta_max", "truncateOverrunN1DeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "truncate_overrun_n1_delta_min": MoPropertyMeta("truncate_overrun_n1_delta_min", "truncateOverrunN1DeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "dropOverrunN0": "drop_overrun_n0", 
        "dropOverrunN0Delta": "drop_overrun_n0_delta", 
        "dropOverrunN0DeltaAvg": "drop_overrun_n0_delta_avg", 
        "dropOverrunN0DeltaMax": "drop_overrun_n0_delta_max", 
        "dropOverrunN0DeltaMin": "drop_overrun_n0_delta_min", 
        "dropOverrunN1": "drop_overrun_n1", 
        "dropOverrunN1Delta": "drop_overrun_n1_delta", 
        "dropOverrunN1DeltaAvg": "drop_overrun_n1_delta_avg", 
        "dropOverrunN1DeltaMax": "drop_overrun_n1_delta_max", 
        "dropOverrunN1DeltaMin": "drop_overrun_n1_delta_min", 
        "intervals": "intervals", 
        "menloQueueComponent": "menlo_queue_component", 
        "menloQueueIndex": "menlo_queue_index", 
        "normalizedTimeCol": "normalized_time_col", 
        "rn": "rn", 
        "statsReported": "stats_reported", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "truncateOverrunN0": "truncate_overrun_n0", 
        "truncateOverrunN0Delta": "truncate_overrun_n0_delta", 
        "truncateOverrunN0DeltaAvg": "truncate_overrun_n0_delta_avg", 
        "truncateOverrunN0DeltaMax": "truncate_overrun_n0_delta_max", 
        "truncateOverrunN0DeltaMin": "truncate_overrun_n0_delta_min", 
        "truncateOverrunN1": "truncate_overrun_n1", 
        "truncateOverrunN1Delta": "truncate_overrun_n1_delta", 
        "truncateOverrunN1DeltaAvg": "truncate_overrun_n1_delta_avg", 
        "truncateOverrunN1DeltaMax": "truncate_overrun_n1_delta_max", 
        "truncateOverrunN1DeltaMin": "truncate_overrun_n1_delta_min", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, menlo_queue_component, menlo_queue_index, **kwargs):
        self._dirty_mask = 0
        self.menlo_queue_component = menlo_queue_component
        self.menlo_queue_index = menlo_queue_index
        self.child_action = None
        self.drop_overrun_n0 = None
        self.drop_overrun_n0_delta = None
        self.drop_overrun_n0_delta_avg = None
        self.drop_overrun_n0_delta_max = None
        self.drop_overrun_n0_delta_min = None
        self.drop_overrun_n1 = None
        self.drop_overrun_n1_delta = None
        self.drop_overrun_n1_delta_avg = None
        self.drop_overrun_n1_delta_max = None
        self.drop_overrun_n1_delta_min = None
        self.intervals = None
        self.normalized_time_col = None
        self.stats_reported = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.truncate_overrun_n0 = None
        self.truncate_overrun_n0_delta = None
        self.truncate_overrun_n0_delta_avg = None
        self.truncate_overrun_n0_delta_max = None
        self.truncate_overrun_n0_delta_min = None
        self.truncate_overrun_n1 = None
        self.truncate_overrun_n1_delta = None
        self.truncate_overrun_n1_delta_avg = None
        self.truncate_overrun_n1_delta_max = None
        self.truncate_overrun_n1_delta_min = None
        self.update = None

        ManagedObject.__init__(self, "AdaptorMenloQStats", parent_mo_or_dn, **kwargs)

